summaryrefslogtreecommitdiff
path: root/gcc/config/ia64
diff options
context:
space:
mode:
authorpinskia <pinskia@138bc75d-0d04-0410-961f-82ee72b054a4>2004-08-13 15:34:00 +0000
committerpinskia <pinskia@138bc75d-0d04-0410-961f-82ee72b054a4>2004-08-13 15:34:00 +0000
commit33f88b1c70435e9803c2dbeffc56522f23484f57 (patch)
tree878c3b36634b01083dbdab85167d3a3f2f7de154 /gcc/config/ia64
parent8833a11bdb254fed3c34d1c00c3a4e1e74ace31e (diff)
downloadgcc-33f88b1c70435e9803c2dbeffc56522f23484f57.tar.gz
2004-08-12 Andrew Pinski <pinskia@physics.uc.edu>
* config/darwin-c.c (find_subframework_file): Fix spelling of cannot. * config/libgloss.h: Likewise. * config/arm/arm.c (arm_gen_load_multiple): Likewise. * c4x/c4x-modes.def: Likewise. * config/c4x/c4x.c (c4x_hard_regno_rename_ok): Likewise. (c4x_rptb_nop_p): Likewise. (c4x_rptb_valid_p): Likewise. (c4x_rptb_insert): Likewise. (c4x_address_conflict): Likewise. * config/c4x/c4x.md: Likewise. * config/frv/frv.md: Likewise. * config/i386/athlon.md: Likewise. * config/i386/i386.md: Likewise. * config/i386/predicates.md: Likewise. * config/ia64/ia64.c: Likewise. * config/ia64/itanium1.md: Likewise. * config/ia64/itanium2.md: Likewise. * config/iq2000/iq2000.md: Likewise. * config/mcore/mcore.c: Likewise. * config/mips/mips.c: Likewise. * config/mips/r3900.h: Likewise. * config/mips/sb1.md: Likewise. * config/pa/milli64.S: Likewise. * config/pa/pa.c: Likewise. * config/pa/pa.h: Likewise. * config/rs6000/8540.md: Likewise. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@85944 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/config/ia64')
-rw-r--r--gcc/config/ia64/ia64.c6
-rw-r--r--gcc/config/ia64/itanium1.md12
-rw-r--r--gcc/config/ia64/itanium2.md16
3 files changed, 17 insertions, 17 deletions
diff --git a/gcc/config/ia64/itanium1.md b/gcc/config/ia64/itanium1.md
index 2b844115160..695b43355f9 100644
--- a/gcc/config/ia64/itanium1.md
+++ b/gcc/config/ia64/itanium1.md
@@ -33,10 +33,10 @@
DEFINE_AUTOMATON).
All define_reservations and define_cpu_units should have unique
- names which can not be "nothing".
+ names which cannot be "nothing".
o (exclusion_set string string) means that each CPU function unit
- in the first string can not be reserved simultaneously with each
+ in the first string cannot be reserved simultaneously with each
unit whose name is in the second string and vise versa. CPU
units in the string are separated by commas. For example, it is
useful for description CPU with fully pipelined floating point
@@ -44,7 +44,7 @@
floating point insns or only double floating point insns.
o (presence_set string string) means that each CPU function unit in
- the first string can not be reserved unless at least one of
+ the first string cannot be reserved unless at least one of
pattern of units whose names are in the second string is
reserved. This is an asymmetric relation. CPU units or unit
patterns in the strings are separated by commas. Pattern is one
@@ -92,13 +92,13 @@
string are separated by commas. Pattern is one unit name or unit
names separated by white-spaces.
- For example, it is useful for description that slot0 can not be
+ For example, it is useful for description that slot0 cannot be
reserved after slot1 or slot2 reservation for a VLIW processor.
We could describe it by the following construction
(absence_set "slot2" "slot0, slot1")
- Or slot2 can not be reserved if slot0 and unit b0 are reserved or
+ Or slot2 cannot be reserved if slot0 and unit b0 are reserved or
slot1 and unit b1 are reserved . In this case we could write
(absence_set "slot2" "slot0 b0, slot1 b1")
@@ -140,7 +140,7 @@
case, you describe common part and use one its name (the 1st
parameter) in regular expression in define_insn_reservation. All
define_reservations, define results and define_cpu_units should
- have unique names which can not be "nothing".
+ have unique names which cannot be "nothing".
o (define_insn_reservation name default_latency condition regexpr)
describes reservation of cpu functional units (the 3nd operand)
diff --git a/gcc/config/ia64/itanium2.md b/gcc/config/ia64/itanium2.md
index 6e71f5b0f9a..b591287950b 100644
--- a/gcc/config/ia64/itanium2.md
+++ b/gcc/config/ia64/itanium2.md
@@ -31,10 +31,10 @@
DEFINE_AUTOMATON).
All define_reservations and define_cpu_units should have unique
- names which can not be "nothing".
+ names which cannot be "nothing".
o (exclusion_set string string) means that each CPU function unit
- in the first string can not be reserved simultaneously with each
+ in the first string cannot be reserved simultaneously with each
unit whose name is in the second string and vise versa. CPU
units in the string are separated by commas. For example, it is
useful for description CPU with fully pipelined floating point
@@ -42,7 +42,7 @@
floating point insns or only double floating point insns.
o (presence_set string string) means that each CPU function unit in
- the first string can not be reserved unless at least one of
+ the first string cannot be reserved unless at least one of
pattern of units whose names are in the second string is
reserved. This is an asymmetric relation. CPU units or unit
patterns in the strings are separated by commas. Pattern is one
@@ -90,13 +90,13 @@
string are separated by commas. Pattern is one unit name or unit
names separated by white-spaces.
- For example, it is useful for description that slot0 can not be
+ For example, it is useful for description that slot0 cannot be
reserved after slot1 or slot2 reservation for a VLIW processor.
We could describe it by the following construction
(absence_set "slot2" "slot0, slot1")
- Or slot2 can not be reserved if slot0 and unit b0 are reserved or
+ Or slot2 cannot be reserved if slot0 and unit b0 are reserved or
slot1 and unit b1 are reserved . In this case we could write
(absence_set "slot2" "slot0 b0, slot1 b1")
@@ -138,7 +138,7 @@
case, you describe common part and use one its name (the 1st
parameter) in regular expression in define_insn_reservation. All
define_reservations, define results and define_cpu_units should
- have unique names which can not be "nothing".
+ have unique names which cannot be "nothing".
o (define_insn_reservation name default_latency condition regexpr)
describes reservation of cpu functional units (the 3nd operand)
@@ -398,7 +398,7 @@
"2_stop")
;; The issue logic can reorder M slot insns between different subtypes
-;; but can not reorder insn within the same subtypes. The following
+;; but cannot reorder insn within the same subtypes. The following
;; constraint is enough to describe this.
(final_presence_set "2_um1" "2_um0")
(final_presence_set "2_um3" "2_um2")
@@ -1274,7 +1274,7 @@
"2b_stop")
;; The issue logic can reorder M slot insns between different subtypes
-;; but can not reorder insn within the same subtypes. The following
+;; but cannot reorder insn within the same subtypes. The following
;; constraint is enough to describe this.
(final_presence_set "2b_um1" "2b_um0")
(final_presence_set "2b_um3" "2b_um2")
diff --git a/gcc/config/ia64/ia64.c b/gcc/config/ia64/ia64.c
index ce48d3fe644..0f7e689f245 100644
--- a/gcc/config/ia64/ia64.c
+++ b/gcc/config/ia64/ia64.c
@@ -4735,7 +4735,7 @@ rtx_needs_barrier (rtx x, struct reg_flags flags, int pred)
}
/* For all ASM_OPERANDS, we must traverse the vector of input operands.
- We can not just fall through here since then we would be confused
+ We cannot just fall through here since then we would be confused
by the ASM_INPUT rtx inside ASM_OPERANDS, which do not indicate
traditional asms unlike their normal usage. */
@@ -5727,7 +5727,7 @@ ia64_first_cycle_multipass_dfa_lookahead_guard (rtx insn)
static rtx dfa_pre_cycle_insn;
/* We are about to being issuing INSN. Return nonzero if we can not
issue it on given cycle CLOCK and return zero if we should not sort
the ready queue on the next clock start. */
@@ -6276,7 +6276,7 @@ get_next_important_insn (rtx insn, rtx tail)
by structure bundle_state (see above). If we generate the same
bundle state (key is automaton state after issuing the insns and
nops for it), we reuse already generated one. As consequence we
- reject some decisions which can not improve the solution and
+ reject some decisions which cannot improve the solution and
reduce memory for the algorithm.
When we reach the end of EBB (extended basic block), we choose the
@@ -5727,7 +5727,7 @@ ia64_first_cycle_multipass_dfa_lookahead_guard (rtx insn)
static rtx dfa_pre_cycle_insn;
-/* We are about to being issuing INSN. Return nonzero if we can not
+/* We are about to being issuing INSN. Return nonzero if we cannot
issue it on given cycle CLOCK and return zero if we should not sort
the ready queue on the next clock start. */